pub enum ThemeMode {
Dark,
Light,
Auto,
}Expand description
Controls which syntax highlighting theme is applied to code blocks.
Variants
Dark
Dark background. Uses “Base16 Eighties Dark”.
Light
Light background. Uses “Solarized (light)”.
Auto
Detects terminal background color at render time using terminal-colorsaurus.
Implementations